@@ -2,6 +2,7 @@ import logging
 import secrets
 import hmac
 from types import SimpleNamespace
+from contextlib import contextmanager
 
 from logchain import formatters
 
@@ -86,6 +87,21 @@ class LogChainer:
 		return Result(True)
 
 
+	def setField(self, **kwargs):
+		"""
+		Adds contextual data to the log record in the form of key = value
+		Remove a key by setting it to `None`.
+		"""
+		self.formatter.setField(**kwargs)
+
+	@contextmanager
+	def managedField(self, **kwargs):
+		try:
+			previousCtx = self.formatter.setField(**kwargs)
+			yield
+		finally:
+			self.formatter.context = previousCtx
+
 def stopLogging():
 	"""
 	Cleanup if needed, inspired from the library source code.
