@@ -30,9 +30,12 @@ class Json(Basic):
 
 
 	def stringify(self, record):
-		subRecord = {f: record.__dict__[f] for f in sorted(self.fields)}
+		subRecord = {f: record.__dict__[f] for f in self.fields}
+		subRecord.update(self.context)
+		subRecord = {key: subRecord[key] for key in sorted(subRecord.keys())}
 		return json.dumps(subRecord, ensure_ascii = False)
 
 	@staticmethod
 	def extractSignature(line):
 		return json.loads(line)["signature"]
+
